@@ -211,7 +211,7 @@ class Form(ABC, metaclass=FormMeta):
             await state.update_data(current_field_name=next_field.name)
             return await message.answer(
                 next_field.info.enter_message_text,
-                reply_markup=next_field.info.reply_markup,
+                reply_markup=next_field.info.reply_markup or REMOVE_MARKUP,
             )
 
         if not cls.__submit_callback:
